package bcd::genisoimage;

use strict;
use XML::Simple;
use bcd::common qw(:DEFAULT $isoconf $wd $name $arch $version);

our @ISA = qw(Exporter);
our @EXPORT = qw(main_iso);
my $LOG="GENISOIMAGE -";

my $builddir = "$wd/$isoconf->{iso}{genisoimage}{builddir}/$name-$version/$arch";
# mandriva-linux-free-2009.1-i586
my $isoname = $isoconf->{nameid} . '-' . $isoconf->{version} . '-' . $isoconf->{arch} . ".iso";

# genisoimage -f -sort /home/plop/tmp/build/2009.1/11.sort  -r -J -hide-rr-moved -nobak -cache-inodes -A "Mandriva Linux - 2009 Spring (Free64)" -publisher "Mandriva" -sysid "Mandriva Linux" -p "Mandriva-Linux" -volset "Mandriva Linux - 2009 Spring (Free64) - DVD x86_64 [1/1]" -V "Free-20091-x86_64" -o /home/plop/iso/2009.1/11-2009.1.iso   -b x86_64/isolinux/isolinux.bin -c x86_64/isolinux/boot.cat -no-emul-boot -boot-load-size 4 -boot-info-table "/home/plop/build/2009.1/first/11" /home/plop/build/2009.1/11


sub create_version {
	# create the VERSION file available on the base of the ISO
    my $version_file = "$builddir/VERSION";
	print "$LOG create the $version_file file\n";
    open my $VERSION, ">$version_file";
    my ($sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst) = gmtime(time());
    $year += 1900;
    my $tag = $isoconf->{iso}{tag};
    my $product = $isoconf->{iso}{product};
    my $publisher = $isoconf->{iso}{header}{publisherid};
    printf $VERSION "$publisher $name $tag %04d%02d%02d $hour:%02d\n", $year, $mon+1, $mday, $min;
    close $VERSION;
}

sub create_productid {
	# vendor=Mandriva,distribution=Mandriva Linux,type=basic,version=2009.1,branch=cooker,release=0.1,arch=i586,product=maratangua
    my $productid_file = "$builddir/product.id";
    open my $product_id, ">>$productid_file";
    print $product_id "vendor=$isoconf->{iso}{header}{publisherid},";
    print $product_id "distribution=$isoconf->{iso}{header}{systemid},";
    print $product_id "type=$isoconf->{iso}{type},";
    print $product_id "version=$version,";
    print $product_id "branch=$isoconf->{iso}{branch},";
    print $product_id "release=$isoconf->{iso}{minor}.$isoconf->{iso}{subversion},";
    print $product_id "arch=$arch,";
    print $product_id "product=$isoconf->{iso}{product}";
    close $product_id;
}

sub create_iso {
	# build the ISO with all args
	print "$LOG Building the ISO\n";
	my $cmd = "genisoimage $isoconf->{iso}{genisoimage}{options} \\
-quiet \\
-A '$isoconf->{iso}{header}{applicationid}' \\
-publisher '$isoconf->{iso}{header}{publisherid}' \\
-sysid '$isoconf->{iso}{header}{systemid}' \\
-p '$isoconf->{iso}{header}{datapreparer}' \\
-volset '$isoconf->{iso}{header}{volumesetid}' \\
-V '$isoconf->{iso}{header}{volumeid}' \\
-o $wd/$isoconf->{iso}{genisoimage}{isodir}/$isoname \\
-b $arch/isolinux/isolinux.bin \\
-boot-info-table $builddir \\
$wd/$isoconf->{iso}{genisoimage}{builddir}/$name-$version
";
#	print "\n------------\n $cmd\n\n";
	system($cmd);
	system("du -h $wd/$isoconf->{iso}{genisoimage}{isodir}/$isoname");
	system("du -sh $builddir/install");

}

sub create_md5 {
	# create the MD5 of the ISO
	print "$LOG Create the MD5 of the ISO\n";
	my $ISOFILE = "$wd/$isoconf->{iso}{genisoimage}{isodir}/$isoname";
	if (! -f $ISOFILE) {
		print "$LOG can't find $ISOFILE\n";
		exit 1;
	} else {
		print "$LOG do a: md5sum $ISOFILE > $ISOFILE.md5\n";
		system("md5sum $ISOFILE > $ISOFILE.md5");
	}
}

sub main_iso {
	create_version;
	create_productid;
	create_iso;
	create_md5;
}

1;

