package bcd::isolinux;

use File::Copy::Recursive qw(dircopy pathrm);
use bcd::common qw(:DEFAULT $isoconf $wd $name $arch $version $repo);

our @ISA = qw(Exporter);
our @EXPORT = qw(main_isolinux);

my $LOG="ISOLINUX -";

my $repo_isolinux;
if ($isoconf->{isolinux}{fullpath} =~ //) {
	$repo_isolinux = "$repo/$version/$arch/$isoconf->{isolinux}{defaultpath}/";
} else {
	$repo_isolinux = $isoconf->{isolinux}{fullpath};
}
my $build_isolinux_dir = "$wd/$isoconf->{iso}{genisoimage}{builddir}/$name-$version/$arch/isolinux";

sub switch_theme {
    my $theme = $isoconf->{theme}{bootsplash};
    print "$LOG switch to theme $theme\n";
    -d "/usr/share/gfxboot/themes/$theme/" or die "$LOG cant find the gfxboot theme";
    opendir my $DIR, $build_isolinux_dir or die "$LOG FATAL switch_theme: unable to open $build_isolinux_dir\n";
    foreach my $f (readdir $DIR){
        $f =~ /^\.{1,2}$/ and next;
        -d "$build_isolinux_dir/$f" or next;
        opendir my $ALT, "$build_isolinux_dir/$f" or die "LOG FATAL switch_theme: unable to open $dir/$f\n";
        foreach my $all (readdir $ALT) {
            $all =~ /all.rdz/ or next;
            my $initrd = "$build_isolinux_dir/$f/$all";
            my $binary = '/usr/share/bootsplash/scripts/make-boot-splash-raw';
            -x $binary or die "$LOG you need $binary which is available in bootsplash >= 3.2.3\n";
            my $cmd = "$binary $initrd 800x600 $theme";
	    print "$LOG using $f\n";
            system($cmd) == 0 or die "$LOG FATAL switch_theme: config file for $theme may not exist\n";
        }
        closedir $ALT
    }
    closedir $DIR;
    # syslinux
    print "$LOG copy/usr/share/bootsplash/themes/$theme/lilo/syslinux $build_isolinux_dir/boot.msg";
    system("cp -vf /usr/share/bootsplash/themes/$theme/lilo/syslinux", "$build_isolinux_dir/boot.msg");
    print "$LOG copy /usr/share/gfxboot/themes/$theme/*.jpg to $build_isolinux_dir/\n";
    system("cp -vf /usr/share/gfxboot/themes/$theme/welcome.jpg $build_isolinux_dir/");
    system("cp -vf /usr/share/gfxboot/themes/$theme/back.jpg $build_isolinux_dir/");
}

sub add_entry {
    my $syslinuxcfg = "$build_isolinux_dir/isolinux/isolinux.cfg";
    foreach my $syslinux (@{$isoconf->{isolinux}{entry}}) {
	$syslinux->{name} or next;
	print "$LOG add $syslinux->{name} in $syslinuxcfg\n";
	open my $SYS, ">> $syslinuxcfg";
	print $SYS "label $syslinux->{label}\n";
	print $SYS "    kernel $syslinux->{kernel}\n";
	print $SYS "    append $syslinux->{append}\n";
	close $SYS;
	-f $syslinux->{bin} and system("$build_isolinux_dir/");
    }
}

sub main_isolinux {
    if (! -d $repo_isolinux) { 
	print "$LOG I can't find the isolinux dir !\n";
	exit;
    }
    print "$LOG Remove old copy of isolinux\n";
    pathrm("$build_isolinux_dir/isolinux") or die $!;
    print "$LOG copy $repo_isolinux to $build_isolinux_dir\n";
    dircopy($repo_isolinux,$build_isolinux_dir) or die $!;
    add_entry;
    switch_theme;
}


1;

