package bcd::media;

use File::Copy::Recursive qw(dircopy pathrm);
use File::Copy;
use bcd::common qw(:DEFAULT $isoconf $wd $name $arch $version $repo);

our @ISA = qw(Exporter);
our @EXPORT = qw(main_media);

my $LOG="MEDIA -";
my $media_dir = "$wd/$isoconf->{iso}{genisoimage}{builddir}/$name-$version/$arch";

my $mediainfo_sourcedir;
if (! $isoconf->{mediainfo}{fullpath}) {
	$mediainfo_sourcedir = $isoconf->{mediainfo}{fullpath};
	print "DEBUG $mediainfo_sourcedir\n";
} else {
	$mediainfo_sourcedir = "$repo/$version/$arch/$isoconf->{mediainfo}{mediainfo_dir}";
}

sub create_media {
    print "$LOG Create the media dir in $media_dir\n";
    foreach my $media (@{$isoconf->{media}{list}}) {
	create_needed_dir("$media_dir/$media->{destmedia}");
    }
}

sub list_media {
    print "$LOG all media are listed there:";
    foreach my $media (@{$isoconf->{media}{list}}) {
    $media->{name} or next;
    print "
name: $media->{name}
    desc: $media->{desc}
    mediadir: $media->{mediadir}
    destmedia: $media->{destmedia}
    pubkey: $media->{pubkey}
\n";
    }
}

sub copy_pubkey {
    my ($source_key, $destmedia) = @_;
    print "$LOG copy $source_key to the $media_dir/$destmedia/media_info directory\n";
    create_needed_dir("$media_dir/$destmedia/media_info/");
    if (! -f $source_key) {
	print "$LOG can't find the $source_key\n";
	exit;
    }
    system("cp -vf $source_key $media_dir/$destmedia/media_info/");
}

sub use_gendistrib {
	print "$LOG gendistrib --mediacfg $media_dir/$isoconf->{iso}{mediacfg} $media_dir";
	system("gendistrib -s --mediacfg $media_dir/$isoconf->{iso}{mediacfg} $media_dir");
}

sub copy_rpm {
	my ($source_dir, $dest_dir) = @_;
	system ("cp -a $source_dir/*.rpm $dest_dir"); 
}

sub create_mediacfg {
    print "$LOG $media_dir/$isoconf->{iso}{mediacfg}\n";
    create_needed_dir("$media_dir/media/media_info");
    my $media_cfg = "$media_dir/$isoconf->{iso}{mediacfg}";
    open my $MEDIACFG, ">>$media_cfg";
    print $MEDIACFG "[media_info]\n";
    print $MEDIACFG "version=$version\n";
    print $MEDIACFG "mediacfg_version=2\n";
    print $MEDIACFG "branch=$isoconf->{iso}{branch} \n";
    print $MEDIACFG "arch=$arch \n";
    print $MEDIACFG "minor=$isoconf->{iso}{minor} \n";
    print $MEDIACFG "subversion=$isoconf->{iso}{subversion} \n";
    print $MEDIACFG "\n";
    if ($isoconf->{suppl}{todo} =~ /yes/) {
        print $MEDIACFG "suppl=1\n";
    }
    if ($isoconf->{askmedia}{todo} =~ /yes/) {
	print $MEDIACFG "askmedia=1\n";
    }
    if ($isoconf->{xml-info}{todo} =~ /yes/) {
	print $MEDIACFG "xml-info=1\n";
    }
    foreach my $media (@{$isoconf->{media}{list}}) {
	$media->{name} or next;
	print $MEDIACFG "
[$media->{name}]
synthesis=../$media->{name}/media_info/synthesis.hdlist.cz
pubkey=../$media->{name}/media_info/pubkey
desc='$media->{desc}'
name=$media->{name}
\n";
        }
    close $MEDIACFG;

}

# import from MDK::common
sub cat_ { my @l = map { my $F; open($F, '<', $_) ? <$F> : () } @_; wantarray() ? @l : join '', @l }

my $listcopy = "/tmp/tocopy";
sub generate_list_of_rpm_2_copy {
    my $opt_sug;
    if ($isoconf->{media}{nosuggests} =~ /yes/) {
	$opt_sug = "--no-suggests";
    }
#	 grep { $_ && !/nodev/ } chomp_(cat_('/etc/filesystems'));
    create_needed_dir("/tmp/$isoconf->{nameid}-$isoconf->{version}-$isoconf->{arch}");
    my $toget;my $toexclude;
    foreach my $tohave (cat_("/home/plop/bcd/input")) {
	if ($tohave =~ /^\s/ || $tohave =~ /^\#/) {
	    next;
	} else {
	    chomp($tohave);
	    $toget = $toget . " " . $tohave;
	    next;
	}
    }
    foreach my $totest (cat_("/home/plop/bcd/exclude")) {
	if ($totest =~ /^\s/ || $totest =~ /^\#/) {
	    next;
	} else {
	    chomp($totest);
	    $toexclude = $toexclude . " --skip " . $totest;
	    next;
	}
    }
    
    my $cmd = "sudo urpmi $opt_sug --no-install --no-verify-rpm --auto -a --test --use-distrib $repo/$version/$arch/ --root /tmp/$isoconf->{nameid}-$isoconf->{version}-$isoconf->{arch}/ $toget $toexclude > $listcopy";
    print "$LOG $cmd \n";
    system($cmd);
}

sub parse_copy {
    foreach my $tocopy (cat_($listcopy)) {
	# use only needed info from urpmi Output (maybe there is some issue with other languages than EN)
	if ($tocopy =~ /^install/ || $tocopy =~ /^\-/ || $tocopy =~ /^More/ || $tocopy =~ /^Install/ ) {
            next;
        } else {
	    print $tocopy;
	    chomp($tocopy);
	    foreach my $media (@{$isoconf->{media}{list}}) {
		    $media->{name} or next;
		if ($tocopy =~ /$media->{mediadir}/) {
		    print "$LOG copy $tocopy TO $media_dir/$media->{destmedia}\n";
		    system("cp -a $tocopy $media_dir/$media->{destmedia}");
		    last;
		}
	    }
	}
	next;
    }
}

sub copy_filesdeps {
	print "$LOG copy $mediainfo_sourcedir/$isoconf->{mediainfo}{filedeps} in $media_dir/media/media_info\n";
	-f "$mediainfo_sourcedir/$isoconf->{mediainfo}{filedeps}" or print "$LOG missing filedpes\n";
	system("cp -vf $mediainfo_sourcedir/$isoconf->{filedeps} $media_dir/media/media_info");
}

sub copy_rpmsrate {
	print "$LOG copy $mediainfo_sourcedir/$isoconf->{mediainfo}{rpmsrate} in $media_dir/media/media_info\n";
	-f "$mediainfo_sourcedir/$isoconf->{mediainfo}{filedeps}" or print "$LOG missing rpmsrate\n";
	system("cp -vf $mediainfo_sourcedir/$isoconf->{mediainfo}{rpmsrate} $media_dir/media/media_info");
}

sub copy_compssusers {
	print "$LOG copy $mediainfo_sourcedir/$isoconf->{mediainfo}{compssusers} in $media_dir/media/media_info\n";
	-f "$mediainfo_sourcedir/$isoconf->{medianfo}{compssusers}" or print "$LOG missing compssusers\n";
	system("cp -vf $mediainfo_sourcedir/$isoconf->{mediainfo}{compssusers} $media_dir/media/media_info");
}

sub use_genhdlist2 {
	foreach my $media (@{$isoconf->{media}{list}}) {
		    $media->{name} or next;
		print "$LOG build synthesys in $media_dir/$media->{destmedia}\n";
		system("genhdlist2 --quiet --clean --file-deps $media_dir/media/media_info/$isoconf->{medianfo}{filedeps} $media_dir/$media->{destmedia}");
	}
}

sub main_media {
    list_media;
    create_media;
    foreach my $media (@{$isoconf->{media}{list}}) {
		    $media->{name} or next;
#		if ($media->{pubkey} =~ //) {
#			print "$LOG no pubkey to copy (usefull when mixing main/contrib packages)\n";
	print "$LOG $repo/$version/$arch/$media->{mediadir}/$media->{pubkey}, $media->{destmedia}\n";
#			} else {
	copy_pubkey("$repo/$version/$arch/$media->{mediadir}/$media->{pubkey}", $media->{destmedia});
#		}
	next;
	}
    create_mediacfg;
    copy_filedeps;
    copy_rpmsrate;
    copy_compssusers;
#    foreach my $media (@{$isoconf->{media}{list}}) {
#	    my $source_rpm;
#	    if ($media->{fullpath_mediadir}) {
#	    	$source_rpm = $media->{fullpath_mediadir};
#	    } else {
#	    	$source_rpm = "$repo/$version/$arch/$media->{mediadir}";
#	    }
#	print "$LOG copy all rpm from $source_rpm to $media_dir/$media->{destmedia}\n";
#    }
    generate_list_of_rpm_2_copy;
    parse_copy;
    use_genhdlist2;
#    use_gendistrib;
}

1;

